;;;; getopt-utils-test.scm

(import test)

(import (only (chicken format) format))
(import (test-utils gloss))

;;;

(test-begin "getopt-utils")

(import getopt-utils)

;;

(define test-predicate? (constantly #t))

(define-constant DEF-DB-PATHNAME "development.sqlite3")
(define-constant DEF-LS-PATHNAME "Artist list.csv")
(define-constant DEF-IM-PATHNAME "curr-images-artists")

(define +loadall?+ #f)
(define +et-directory+)
(define +ls-pathname+)
(define +db-pathname+)
(define +im-directory+)

(define (print-results)
  (glossf "loadall?: ~S" +loadall?+)
  (glossf "input ls: ~S" +ls-pathname+)
  (glossf "input et: ~S" +et-directory+)
  (glossf "output im: ~S" +im-directory+)
  (glossf "output db: ~S" +db-pathname+) )

(define (processs-options params)
  (glossf "params: ~S" params)
  (opt-set! +loadall?+ 'loadall params)
  (opt-set! +et-directory+ 'et params)
  (opt-set! +ls-pathname+ 'ls params)
  (opt-set! +im-directory+ 'im params)
  (opt-set! +db-pathname+ 'db params)
  (glossf "rest: ~S" (opt-rest params)) )

(define +opt-grammar+ (extend-opt-grammar #t
  (loadall "assume no \"old\" entries")
  (et "entry thingy directory"
    (value
      (required ET-PATHNAME)
      (predicate ,test-predicate?) ) )
  (ls ,(opt-docstring "artist list CSV pathname" DEF-LS-PATHNAME)
    (value
      (optional LS-PATHNAME)
      (predicate ,test-predicate?) ) )
  (im ,(opt-docstring "artist images directory" DEF-IM-PATHNAME)
    (value
      (optional IM-PATHNAME)
      (predicate ,test-predicate?) ) )
  (db ,(opt-docstring "database pathname" DEF-DB-PATHNAME)
    (value
      (optional DB-PATHNAME)
      (predicate ,test-predicate?) ) )
))

(define +opt-parameters+ '(
  (message . " <options>")
  (width . 48)
  ;(command .  "TEST")
))

;;

(define (main args)
  (glossf "args: ~A" args)
  (let ((params (opt-parse args +opt-grammar+ +opt-parameters+)))
    (processs-options params)
    (print-results) ) )

;;

(begin
  (gloss)
  (main '()) )

(begin
  (gloss)
  (main '("--loadall" "--db=/foo/bar" "the" "rest")) )

#; ;FIXME need failure test(s)
(begin
  (gloss)
  (main '("-loadall" "-db=/foo/bar")) )


#| ;XXX what was to be tested?
(import getopt-long)

(define (Xmake-option-dispatch params grammar)
)

(define (Xprocesss-options opt-get)
  (set! +loadall?+ (opt-get 'loadall))
  (set! +et-directory+ (opt-get 'et))
  (set! +ls-pathname+ (opt-get 'ls))
  (set! +im-directory+ (opt-get 'im))
  (set! +db-pathname+ (opt-get 'db)))

(define (Xmain args)
  (glossf "args: ~S" args)
  (let ((params (opt-parse args +opt-grammar+ +opt-parameters+)))
    (define opt-get (Xmake-option-dispatch params +opt-grammar+))
    (Xprocesss-options opt-get)
    (print-results) ) )

(print)
(Xmain '("--loadall" "--db=/foo/bar"))
|#

;;;

(test-end "getopt-utils")

(test-exit)
